===============================
pvl
===============================

.. image:: https://badge.fury.io/py/pvl.svg
    :target: http://badge.fury.io/py/pvl

.. image:: https://travis-ci.org/planetarypy/pvl.svg?branch=master
        :target: https://travis-ci.org/planetarypy/pvl

.. image:: https://pypip.in/d/pvl/badge.png
        :target: https://pypi.python.org/pypi/pvl


Python implementation of PVL (Parameter Value Language)

* Free software: BSD license
* Documentation: http://pvl.readthedocs.org.

Features
--------

* TODO